@@ -17,10 +17,6 @@
 #endif
   def (name)
   def (title)
-#if BG_IMAGE_FROM_FILE
-  def (path)
-  def (backgroundPixmap)
-#endif
   def (loginShell)
   def (multiClickTime)
   def (jumpScroll)
@@ -59,11 +55,6 @@
   def (preeditType)
   def (inputMethod)
 #endif
-#if BG_IMAGE_FROM_ROOT
-  def (transparent)
-  def (shade)
-  def (blurradius)
-#endif
 #if XFT
   def (buffered)
 #endif
@@ -94,7 +85,10 @@
   def (cutchars)
   def (modifier)
   def (answerbackstring)
+#if ENABLE_FRILLS
   def (tripleclickwords)
+  def (disablePasteBrackets)
+#endif
   def (insecure)
   def (pointerBlank)
   def (pointerBlankDelay)
@@ -105,6 +99,9 @@
   def (secondaryScreen)
   def (secondaryScroll)
 #endif
+#if ENABLE_FRILLS
+  def (rewrapMode)
+#endif
 #if OFF_FOCUS_FADING
   def (fade)
 #endif
